#' @name limonaid-package
#' @title limonaid-package
#' @aliases limonaid-package limonaid
#' @description Working With LimeSurvey Surveys and Responses
#' @details LimeSurvey is Free/Libre Open Source Software for
#' the development and administrations of online studies, using
#' sophisticated tailoring capabilities to support multiple study
#' designs. This package supports programmatic creation of surveys
#' that can then be imported into LimeSurvey, as well as
#' userfriendly import of responses from LimeSurvey studies.
#' @author Gjalt-Jorn Peters <limonaid@opens.science>
#' @keywords package
"_PACKAGE"
